Crate tixml2svd

Crate tixml2svd 

Structs

Args
This structure contains arguments used to customize the behavior of tixml2svd.

Functions

get_parser_from_filename
Used by process_device_base to open each peripheral file and provide a xml parser for the file. It only makes sense to replace this if you wish to run this code without file-based storage.
process_device
Convert a TIXML device to SVD.
process_device_base
Convert a TIXML device to SVD.
process_peripheral
Convert a TIXML peripheral to SVD.
process_peripheral_base
Convert a TIXML peripheral to SVD.