Structs
- Args
- This structure contains arguments used to customize the behavior of tixml2svd.
Functions
- get_
parser_ from_ filename - Used by process_device_base to open each peripheral file and provide a xml parser for the file. It only makes sense to replace this if you wish to run this code without file-based storage.
- process_
device - Convert a TIXML device to SVD.
- process_
device_ base - Convert a TIXML device to SVD.
- process_
peripheral - Convert a TIXML peripheral to SVD.
- process_
peripheral_ base - Convert a TIXML peripheral to SVD.